# CRC4

> RC4 encryption for python in C

# Installation

```sh
pip install crc4
```

# Timing

```
Timing tests...
Python... 1.4859342069994455
C... 0.08101043699934962
```

C is over 18 times faster.
